from django.dispatch import receiver
from django.shortcuts import reverse
from dynamic_preferences.registries import global_preferences_registry

from shiftregister.core.signals import populate_nav

from .models import IncomingMessage

global_preferences = global_preferences_registry.manager()


@receiver(populate_nav, dispatch_uid="populate_team_nav")
def populate_team_nav(sender, **kwargs):
    request = sender
    nav_items = []

    is_not_over = global_preferences["helper__event_state"] != "AFTER"
    if request.user.is_authenticated:
        if is_not_over:
            nav_items.append(
                {"link": reverse("team:shift_overview"), "text": "Schichtübersicht"}
            )
        nav_items.append({"link": reverse("team:checkins"), "text": "Checkin"})
        if is_not_over:
            nav_items.append(
                {"link": reverse("team:shift_free"), "text": "Freie Schichten"}
            )
        nav_items.append({"link": reverse("team:shift_all"), "text": "Alle Schichten"})
        nav_items.append(
            {"link": reverse("team:bulk_message"), "text": "Massen-Nachricht"}
        )

        num_unread = IncomingMessage.objects.filter(read=False).count()
        nav_items.append(
            {
                "link": reverse("team:incoming_messages"),
                "text": "Eingehende Nachrichten"
                + (f" ({num_unread})" if num_unread else ""),
            }
        )

    return nav_items
